@@ -5,6 +5,7 @@ https://github.com/Ernst79/bleparser/blob/c42ae922e1abed2720c7fac993777e1bd59c0c
 
 MIT License applies.
 """
+
 from __future__ import annotations
 
 import logging
@@ -30,6 +31,9 @@ DEVICE_TYPES = {
     0x10: ThermoBeaconDevice("16", "Lanyard/mini hygrometer"),
     0x11: ThermoBeaconDevice("17", "Smart hygrometer"),
     0x15: ThermoBeaconDevice("21", "Smart hygrometer"),
+    0x18: ThermoBeaconDevice("24", "Smart hygrometer"),
+    0x1B: ThermoBeaconDevice("27", "Smart hygrometer"),
+    0x30: ThermoBeaconDevice("48", "Smart hygrometer"),
 }
 MFR_IDS = set(DEVICE_TYPES)
 
@@ -60,7 +64,6 @@ class ThermoBeaconBluetoothDeviceData(BluetoothData):
         device_id = data[0]
         device_type = DEVICE_TYPES[device_id]
         name = device_type.name
-        self.set_precision(2)
         self.set_device_type(device_id)
         self.set_title(f"{name} {short_address(service_info.address)}")
         self.set_device_name(f"{name} {short_address(service_info.address)}")
@@ -94,7 +97,9 @@ class ThermoBeaconBluetoothDeviceData(BluetoothData):
         else:
             batt = 0
 
+        self.set_precision(0)
         self.update_predefined_sensor(SensorLibrary.BATTERY__PERCENTAGE, batt)
+        self.set_precision(2)
         self.update_predefined_sensor(SensorLibrary.TEMPERATURE__CELSIUS, temp)
         self.update_predefined_sensor(SensorLibrary.HUMIDITY__PERCENTAGE, humi)
         self.update_predefined_sensor(
